==> lhcsmapi-1.1.123.tar.gz: lhcsmapi-1.1.123/test/test_dbsignal/test_SignalUtilities.py <==

import unittest
import pandas as pd
import numpy as np
from copy import deepcopy
from tzlocal import get_localzone
from lhcsmapi.dbsignal.SignalUtilities import SignalUtilities as su


class TestSignalUtils(unittest.TestCase):
    """"test class for DataFrameConverter. Tests index conversion methods on dataFrame with 100 entries"""

    def setUp(self):
        self.unixTimeSeconds = [
            1534597678.620001, 1534597679.120001, 1534597738.620001, 1534597739.120001, 1534597798.620001,
            1534597799.120001, 1534597829.620001, 1534597830.120001, 1534597833.620001, 1534597834.120001,
            1534597836.620001, 1534597837.120001, 1534597839.120001, 1534597839.620001, 1534597841.120001,
            1534597841.620001, 1534597843.120001, 1534597843.620001, 1534597845.120001, 1534597845.620001,
            1534597847.120001, 1534597847.620001, 1534597848.620001, 1534597849.120001, 1534597850.120001,
            1534597850.620001, 1534597851.620001, 1534597852.120001, 1534597853.120001, 1534597853.620001,
            1534597854.620001, 1534597855.120001, 1534597856.120001, 1534597856.620001, 1534597857.620001,
            1534597858.120001, 1534597859.120001, 1534597859.620001, 1534597860.120001, 1534597860.620001,
            1534597861.120001, 1534597861.620001, 1534597862.120001, 1534597862.620001, 1534597863.120001,
            1534597863.620001, 1534597864.120001, 1534597864.620001, 1534597865.120001, 1534597865.620001,
            1534597866.120001, 1534597866.620001, 1534597867.120001, 1534597867.620001, 1534597868.120001,
            1534597868.620001, 1534597869.120001, 1534597869.620001, 1534597870.120001, 1534597870.620001,
            1534597871.120001, 1534597871.620001, 1534597872.120001, 1534597872.620001, 1534597873.120001,
            1534597873.620001, 1534597874.120001, 1534597874.620001, 1534597875.120001, 1534597875.620001,
            1534597876.120001, 1534597876.620001, 1534597877.120001, 1534597877.620001, 1534597878.120001,
            1534597878.620001, 1534597879.120001, 1534597879.620001, 1534597880.120001, 1534597880.620001,
            1534597881.120001, 1534597881.620001, 1534597882.120001, 1534597882.620001, 1534597883.120001,
            1534597883.620001, 1534597884.120001, 1534597884.620001, 1534597885.120001, 1534597885.620001,
            1534597886.120001, 1534597886.620001, 1534597887.120001, 1534597887.620001, 1534597888.120001,
            1534597888.620001, 1534597889.120001, 1534597889.620001, 1534597890.120001, 1534597890.620001]

        self.unixTimeNanoseconds = [
            1534597678620001000, 1534597679120001000, 1534597738620001000, 1534597739120001000, 1534597798620001000,
            1534597799120001000, 1534597829620001000, 1534597830120001000, 1534597833620001000, 1534597834120001000,
            1534597836620001000, 1534597837120001000, 1534597839120001000, 1534597839620001000, 1534597841120001000,
            1534597841620001000, 1534597843120001000, 1534597843620001000, 1534597845120001000, 1534597845620001000,
            1534597847120001000, 1534597847620001000, 1534597848620001000, 1534597849120001000, 1534597850120001000,
            1534597850620001000, 1534597851620001000, 1534597852120001000, 1534597853120001000, 1534597853620001000,
            1534597854620001000, 1534597855120001000, 1534597856120001000, 1534597856620001000, 1534597857620001000,
            1534597858120001000, 1534597859120001000, 1534597859620001000, 1534597860120001000, 1534597860620001000,
            1534597861120001000, 1534597861620001000, 1534597862120001000, 1534597862620001000, 1534597863120001000,
            1534597863620001000, 1534597864120001000, 1534597864620001000, 1534597865120001000, 1534597865620001000,
            1534597866120001000, 1534597866620001000, 1534597867120001000, 1534597867620001000, 1534597868120001000,
            1534597868620001000, 1534597869120001000, 1534597869620001000, 1534597870120001000, 1534597870620001000,
            1534597871120001000, 1534597871620001000, 1534597872120001000, 1534597872620001000, 1534597873120001000,
            1534597873620001000, 1534597874120001000, 1534597874620001000, 1534597875120001000, 1534597875620001000,
            1534597876120001000, 1534597876620001000, 1534597877120001000, 1534597877620001000, 1534597878120001000,
            1534597878620001000, 1534597879120001000, 1534597879620001000, 1534597880120001000, 1534597880620001000,
            1534597881120001000, 1534597881620001000, 1534597882120001000, 1534597882620001000, 1534597883120001000,
            1534597883620001000, 1534597884120001000, 1534597884620001000, 1534597885120001000, 1534597885620001000,
            1534597886120001000, 1534597886620001000, 1534597887120001000, 1534597887620001000, 1534597888120001000,
            1534597888620001000, 1534597889120001000, 1534597889620001000, 1534597890120001000, 1534597890620001000]

        self.timestamps = [pd.Timestamp(t, tz=get_localzone()) for t in self.unixTimeNanoseconds]

        y = np.arange(100)
        self.dfIndexInSeconds = pd.DataFrame(y, self.unixTimeSeconds)
        self.dfIndexInNanoseconds = pd.DataFrame(y, self.unixTimeNanoseconds)
        self.dfIndexInTimestamps = pd.DataFrame(y, self.timestamps)

    def tearDown(self):
        pass

    def test(self):
        pass

    def test_convertIndexFromNanosecondsToSeconds_convertsIndexCorrectly(self):
        """Tests that convertIndexFromNanosecondsToSeconds correctly converts the index of a DataFrame with 100 entries
        from ns to seconds"""

        df = deepcopy(self.dfIndexInNanoseconds)
        df = su.convertIndicesToSeconds(df)

        pd.testing.assert_frame_equal(df, self.dfIndexInSeconds)

    def test_convertIndexFromSecondsToNanoseconds_convertsIndexCorrectly(self):
        """Tests that convertIndexFromSecondsToNanoseconds correctly converts the index of a DataFrame with 100 entries
        from seconds to ns"""

        df = deepcopy(self.dfIndexInSeconds)
        df = su.convertIndicesToUnixTimestamp(df, 's')

        pd.testing.assert_frame_equal(df, self.dfIndexInNanoseconds)

    def test_convertIndexFromNanosecondsToTimestamps_convertsIndexCorrectly(self):
        """Tests that convertIndexFromNanosecondsToTimestamps correctly converts the index of a DataFrame with 100 entries
        from ns to Timestamp objects"""

        df = deepcopy(self.dfIndexInNanoseconds)
        df = su.convertIndicesToTimestamps(df)

        pd.testing.assert_frame_equal(df, self.dfIndexInTimestamps)

    def test_convertIndexFromTimestampsToNanoseconds_convertsIndexCorrectly(self):
        """Tests that convertIndexFromTimestampsToNanoseconds correctly converts the index of a DataFrame with 100 entries
        from Timestamp objects to ns"""

        df = deepcopy(self.dfIndexInTimestamps)
        df = su.convertIndicesToUnixTimestamp(df)

        pd.testing.assert_frame_equal(df, self.dfIndexInNanoseconds)

if __name__ == '__main__':
    unittest.main()

==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/test/test_dbsignal/test_SignalUtilities.py <==

import unittest
import pandas as pd
import numpy as np
from copy import deepcopy
from tzlocal import get_localzone
from lhcsmapi.dbsignal.SignalUtilities import SignalUtilities as su


class TestSignalUtils(unittest.TestCase):
    """"test class for DataFrameConverter. Tests index conversion methods on dataFrame with 100 entries"""

    def setUp(self):
        self.unixTimeSeconds = [
            1534597678.620001, 1534597679.120001, 1534597738.620001, 1534597739.120001, 1534597798.620001,
            1534597799.120001, 1534597829.620001, 1534597830.120001, 1534597833.620001, 1534597834.120001,
            1534597836.620001, 1534597837.120001, 1534597839.120001, 1534597839.620001, 1534597841.120001,
            1534597841.620001, 1534597843.120001, 1534597843.620001, 1534597845.120001, 1534597845.620001,
            1534597847.120001, 1534597847.620001, 1534597848.620001, 1534597849.120001, 1534597850.120001,
            1534597850.620001, 1534597851.620001, 1534597852.120001, 1534597853.120001, 1534597853.620001,
            1534597854.620001, 1534597855.120001, 1534597856.120001, 1534597856.620001, 1534597857.620001,
            1534597858.120001, 1534597859.120001, 1534597859.620001, 1534597860.120001, 1534597860.620001,
            1534597861.120001, 1534597861.620001, 1534597862.120001, 1534597862.620001, 1534597863.120001,
            1534597863.620001, 1534597864.120001, 1534597864.620001, 1534597865.120001, 1534597865.620001,
            1534597866.120001, 1534597866.620001, 1534597867.120001, 1534597867.620001, 1534597868.120001,
            1534597868.620001, 1534597869.120001, 1534597869.620001, 1534597870.120001, 1534597870.620001,
            1534597871.120001, 1534597871.620001, 1534597872.120001, 1534597872.620001, 1534597873.120001,
            1534597873.620001, 1534597874.120001, 1534597874.620001, 1534597875.120001, 1534597875.620001,
            1534597876.120001, 1534597876.620001, 1534597877.120001, 1534597877.620001, 1534597878.120001,
            1534597878.620001, 1534597879.120001, 1534597879.620001, 1534597880.120001, 1534597880.620001,
            1534597881.120001, 1534597881.620001, 1534597882.120001, 1534597882.620001, 1534597883.120001,
            1534597883.620001, 1534597884.120001, 1534597884.620001, 1534597885.120001, 1534597885.620001,
            1534597886.120001, 1534597886.620001, 1534597887.120001, 1534597887.620001, 1534597888.120001,
            1534597888.620001, 1534597889.120001, 1534597889.620001, 1534597890.120001, 1534597890.620001]

        self.unixTimeNanoseconds = [
            1534597678620001000, 1534597679120001000, 1534597738620001000, 1534597739120001000, 1534597798620001000,
            1534597799120001000, 1534597829620001000, 1534597830120001000, 1534597833620001000, 1534597834120001000,
            1534597836620001000, 1534597837120001000, 1534597839120001000, 1534597839620001000, 1534597841120001000,
            1534597841620001000, 1534597843120001000, 1534597843620001000, 1534597845120001000, 1534597845620001000,
            1534597847120001000, 1534597847620001000, 1534597848620001000, 1534597849120001000, 1534597850120001000,
            1534597850620001000, 1534597851620001000, 1534597852120001000, 1534597853120001000, 1534597853620001000,
            1534597854620001000, 1534597855120001000, 1534597856120001000, 1534597856620001000, 1534597857620001000,
            1534597858120001000, 1534597859120001000, 1534597859620001000, 1534597860120001000, 1534597860620001000,
            1534597861120001000, 1534597861620001000, 1534597862120001000, 1534597862620001000, 1534597863120001000,
            1534597863620001000, 1534597864120001000, 1534597864620001000, 1534597865120001000, 1534597865620001000,
            1534597866120001000, 1534597866620001000, 1534597867120001000, 1534597867620001000, 1534597868120001000,
            1534597868620001000, 1534597869120001000, 1534597869620001000, 1534597870120001000, 1534597870620001000,
            1534597871120001000, 1534597871620001000, 1534597872120001000, 1534597872620001000, 1534597873120001000,
            1534597873620001000, 1534597874120001000, 1534597874620001000, 1534597875120001000, 1534597875620001000,
            1534597876120001000, 1534597876620001000, 1534597877120001000, 1534597877620001000, 1534597878120001000,
            1534597878620001000, 1534597879120001000, 1534597879620001000, 1534597880120001000, 1534597880620001000,
            1534597881120001000, 1534597881620001000, 1534597882120001000, 1534597882620001000, 1534597883120001000,
            1534597883620001000, 1534597884120001000, 1534597884620001000, 1534597885120001000, 1534597885620001000,
            1534597886120001000, 1534597886620001000, 1534597887120001000, 1534597887620001000, 1534597888120001000,
            1534597888620001000, 1534597889120001000, 1534597889620001000, 1534597890120001000, 1534597890620001000]

        self.timestamps = [pd.Timestamp(t, tz=get_localzone()) for t in self.unixTimeNanoseconds]

        y = np.arange(100)
        self.dfIndexInSeconds = pd.DataFrame(y, self.unixTimeSeconds)
        self.dfIndexInNanoseconds = pd.DataFrame(y, self.unixTimeNanoseconds)
        self.dfIndexInTimestamps = pd.DataFrame(y, self.timestamps)

    def tearDown(self):
        pass

    def test(self):
        pass

    def test_convertIndexFromNanosecondsToSeconds_convertsIndexCorrectly(self):
        """Tests that convertIndexFromNanosecondsToSeconds correctly converts the index of a DataFrame with 100 entries
        from ns to seconds"""

        df = deepcopy(self.dfIndexInNanoseconds)
        df = su.convert_indices_to_sec(df)

        pd.testing.assert_frame_equal(df, self.dfIndexInSeconds)

    def test_convertIndexFromSecondsToNanoseconds_convertsIndexCorrectly(self):
        """Tests that convertIndexFromSecondsToNanoseconds correctly converts the index of a DataFrame with 100 entries
        from seconds to ns"""

        df = deepcopy(self.dfIndexInSeconds)
        df = su.convert_indices_to_unix_timestamp(df, 's')

        pd.testing.assert_frame_equal(df, self.dfIndexInNanoseconds)

    def test_convertIndexFromNanosecondsToTimestamps_convertsIndexCorrectly(self):
        """Tests that convertIndexFromNanosecondsToTimestamps correctly converts the index of a DataFrame with 100 entries
        from ns to Timestamp objects"""

        df = deepcopy(self.dfIndexInNanoseconds)
        df = su.convert_indices_to_timestamps(df)

        pd.testing.assert_frame_equal(df, self.dfIndexInTimestamps)

    def test_convertIndexFromTimestampsToNanoseconds_convertsIndexCorrectly(self):
        """Tests that convertIndexFromTimestampsToNanoseconds correctly converts the index of a DataFrame with 100 entries
        from Timestamp objects to ns"""

        df = deepcopy(self.dfIndexInTimestamps)
        df = su.convert_indices_to_unix_timestamp(df)

        pd.testing.assert_frame_equal(df, self.dfIndexInNanoseconds)

if __name__ == '__main__':
    unittest.main()
